@@ -16,8 +16,7 @@
 use indexmap::IndexMap;
 use serde::Deserialize;
 use std::collections::HashMap;
-use std::path::Path;
-use std::{fs, string::String};
+use std::string::String;
 
 pub(crate) type EnvironmentVariables = IndexMap<String, EnvValue>;
 
@@ -31,16 +30,8 @@ pub(crate) struct ConfigFile {
 }
 
 impl ConfigFile {
-    pub(crate) fn load(path: &Path) -> FileResult {
-        let toml_string = match fs::read_to_string(path) {
-            Ok(valid_file) => valid_file,
-            Err(_) => return FileResult::NotFound,
-        };
-        let config = match toml::from_str(toml_string.as_str()) {
-            Ok(config) => config,
-            Err(_) => return FileResult::Invalid,
-        };
-        FileResult::Success(config)
+    pub(crate) fn load(toml_string: String) -> Result<ConfigFile, toml::de::Error> {
+        toml::from_str(&*toml_string)
     }
 }
 
@@ -51,12 +42,3 @@ pub(crate) enum EnvValue {
     String(String),
     Array(Vec<String>),
 }
-
-/// Enum of all potential outcomes of attempting to read the configuration file.
-pub(crate) enum FileResult {
-    Success(ConfigFile),
-
-    // Errors
-    NotFound,
-    Invalid,
-}
